import { GRAPHQL_AUTH_MODE } from "@aws-amplify/api";
import { CreateParams, CreateResult, DeleteManyParams, DeleteManyResult, DeleteParams, DeleteResult, GetListParams, GetListResult, GetManyParams, GetManyReferenceParams, GetManyReferenceResult, GetManyResult, GetOneParams, GetOneResult, UpdateManyParams, UpdateManyResult, UpdateParams, UpdateResult } from "ra-core";
export interface Operations {
    queries: Record<string, string>;
    mutations: Record<string, string>;
}
export interface DataProviderOptions {
    authMode?: GRAPHQL_AUTH_MODE;
    storageBucket?: string;
    storageRegion?: string;
    enableAdminQueries?: boolean;
}
export declare class DataProvider {
    queries: Record<string, string>;
    mutations: Record<string, string>;
    authMode: GRAPHQL_AUTH_MODE;
    enableAdminQueries: boolean;
    static storageBucket?: string;
    static storageRegion?: string;
    constructor(operations: Operations, options?: DataProviderOptions);
    getList: <RecordType>(resource: string, params: GetListParams) => Promise<GetListResult<RecordType>>;
    getOne: <RecordType>(resource: string, params: GetOneParams) => Promise<GetOneResult<RecordType>>;
    getMany: <RecordType>(resource: string, params: GetManyParams) => Promise<GetManyResult<RecordType>>;
    getManyReference: <RecordType>(resource: string, params: GetManyReferenceParams) => Promise<GetManyReferenceResult<RecordType>>;
    create: <RecordType>(resource: string, params: CreateParams) => Promise<CreateResult<RecordType>>;
    update: <RecordType>(resource: string, params: UpdateParams) => Promise<UpdateResult<RecordType>>;
    updateMany: (resource: string, params: UpdateManyParams) => Promise<UpdateManyResult>;
    delete: <RecordType>(resource: string, params: DeleteParams) => Promise<DeleteResult<RecordType>>;
    deleteMany: (resource: string, params: DeleteManyParams) => Promise<DeleteManyResult>;
    getQuery(queryName: string): string;
    getQueryName(operation: string, resource: string): string;
    getQueryNameMany(operation: string, resource: string, target: string): string;
    graphql(query: string, variables: Record<string, unknown>): Promise<any>;
}
